/****************************
 *  An example sketch that waits for character input on TX to 
 *  print the relative humidty of the temperautre in degrees
 *  celsius to the RX characteristic of the BLE Shield.
 *  by Dr. Michael Kroll 2012
 *  v1.0.0 2012-08-22
 *
 *  Tested with the SHT21-Breakout
 *  Humidity sensor from Modern Device:
 *
 *  http://http://shop.moderndevice.com/products/humidity-and-temperature-sensor
 *
 * Can also be used with the SHT15 breakput board from Sparkfun:
 * https://www.sparkfun.com/products/8257
 *
 *****************************/
#include <Wire.h>
#include <LibHumidity.h>

LibHumidity sht21 = LibHumidity(0);

void setup() {
  Serial.begin(19200);
  pinMode(16, OUTPUT);
  digitalWrite(16, LOW);  //GND pin
  pinMode(17, OUTPUT);
  digitalWrite(17, HIGH); //VCC pin
}

void loop() {

  // Wait for a 'c' to write the temperature to the RX characteristic
  // and a 'h' to write the humidity to the RX characteristic.
  if (Serial.available()) {
    char c = Serial.read();
    if (c == 'c') {
      writeTemperature();
    }
    else if (c == 'h') {
      writeHumidity();
    }
  }
}

void writeTemperature() {
  float temp = sht21.GetTemperatureC();
  Serial.print(temp);
  Serial.print(" C");
  // Fill the BLE Shields 16 byte buffer with spaces!
  if (temp >= 10.0) {
    Serial.print("         ");
  }
  else {
    Serial.print("          ");
  }  
}

void writeHumidity() {
  float humidity = sht21.GetHumidity();
  Serial.print(humidity);
  Serial.print(" %");
  // Fill the BLE Shields 16 byte buffer with spaces!
  if (humidity >= 10.0) {
    Serial.print("         ");
  }
  else {
    Serial.print("          ");
  }
}
